@@ -83,8 +83,14 @@ class Git:
     def get_url(self, rpath, remote_name):
         config = ConfigParser(strict=False)
         config.read(path.join(Git._gitDir(rpath), "config"), encoding="utf-8")
-        return config.get('remote "%s"' % remote_name, "url",
-                          raw=True, fallback="")
+        res = config.get('remote "%s"' % remote_name, "url",
+                         raw=True, fallback="")
+        if res:
+            return res
+        fetch_info = self._getFetchHeadInfo(Git._gitDir(rpath))
+        if "url" in fetch_info:
+            return fetch_info['url']
+        return ""
 
     def cloneRepository(self, url, rpath, branch, cb_progress=None):
         """
@@ -154,15 +160,15 @@ class Git:
             return d
         return {}
 
-    def _copy_index(self, git_dir, file_url):
+    def _copy_file(self, git_dir, file_url, fn):
         """
         Переместить index файл из одного репозитория в другой
         :param git_dir:
         :param file_url:
         :return:
         """
-        old_index = path.join(file_url[7:], "index")
-        new_index = path.join(git_dir, "index")
+        old_index = path.join(file_url[7:], fn)
+        new_index = path.join(git_dir, fn)
         if path.exists(old_index):
             try:
                 with open(old_index, 'r') as in_f:
@@ -210,7 +216,7 @@ class Git:
         # получить последние коммиты из удаленного репозитория
         if command("init"):
             if copy_index:
-                copy_index = self._copy_index(git_dir, url)
+                copy_index = self._copy_file(git_dir, url, "index")
             if copy_index:
                 command_fetch(part=3)
                 fetch_type = self.saveFetchHead(git_dir)
@@ -252,9 +258,12 @@ class Git:
         except OSError:
             raise GitError(_("Failed to optimize repository %s") % rpath)
 
-        self.cloneTagRepository("file://%s" % git_dir_old,
+        file_url = "file://%s" % git_dir_old
+        self.cloneTagRepository(file_url,
                                 rpath, reference, cb_progress,
                                 copy_index=True)
+        self._copy_file(git_dir, file_url, "config")
+        self._copy_file(git_dir, file_url, "FETCH_HEAD")
         try:
             removeDir(git_dir_old)
         except Exception:
