@@ -193,6 +193,16 @@ class Locale(object):
             'xkblayout': 'fr',
             'language': 'fr',
         }),
+        ('hr_HR', {
+            'name': 'Hrvatski (Hrvatska)',
+            'locale': 'hr_HR.UTF-8',
+            'keymap': 'croat',
+            'timezone': 'Europe/Zagreb',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'hr',
+            'language': 'hr',
+        }),
         ('is_IS', {
             'name': 'Íslenska (Ísland)',
             'locale': 'is_IS.UTF-8',
